@@ -315,4 +315,9 @@ class TeradataAdapter(SQLAdapter):
             else:
                 grants_dict.update({privilege: [grantee]})
         return grants_dict
-    
\ No newline at end of file
+    
+    def valid_incremental_strategies(self):
+        """The set of standard builtin strategies which this adapter supports out-of-the-box.
+        Not used to validate custom strategies defined by end users.
+        """
+        return ["delete+insert","append"]
\ No newline at end of file
