@@ -196,9 +196,15 @@
 
   {% endif %}
 
+  -- apply grants
+  {%- set grant_config = config.get('grants') -%}
+  {% set should_revoke = should_revoke(target_relation_exists, full_refresh_mode) %}
+  {% do apply_grants(target_relation, grant_config, should_revoke) %}
+
   {% do persist_docs(target_relation, model) %}
 
   {{ run_hooks(post_hooks, inside_transaction=True) }}
+  
 
   {{ adapter.commit() }}
 
